[![Build Status](https://travis-ci.org/adewes/beam-up.svg?branch=master)](https://travis-ci.org/adewes/beam-up)

Beam is a static page builder used by KIProtect and Algoner.

Currently there is no public documentation available, sorry!
